<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                xmlns:lab="urn:oid:1.3.6.1.4.1.19376.1.3.2"
                xmlns:sdtc="urn:hl7-org:sdtc"
                xmlns:hl7nl="urn:hl7-nl:v3"
                xmlns:nfu="urn:urn:nictiz-nl:v3/nfu"
                xmlns:pharm="urn:ihe:pharm:medication"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title="Schematron file for transaction Technisch bevestiging laboratoriumresultaten (2.16.840.1.113883.2.4.3.11.60.25.4.16 2018-11-05T16:53:25)"
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="cda"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v2xml" prefix="hl7v2"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:oid:1.3.6.1.4.1.19376.1.3.2" prefix="lab"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:sdtc" prefix="sdtc"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-nl:v3" prefix="hl7nl"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:urn:nictiz-nl:v3/nfu" prefix="nfu"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:ihe:pharm:medication" prefix="pharm"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">ACK_Lab</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013</xsl:attribute>
            <xsl:attribute name="name">Lab ACK - Acknowledgement Message</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013-closed</xsl:attribute>
            <xsl:attribute name="name">Lab ACK - Acknowledgement Message</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Schematron file for transaction Technisch bevestiging laboratoriumresultaten (2.16.840.1.113883.2.4.3.11.60.25.4.16 2018-11-05T16:53:25)</svrl:text>

   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*" mode="M12"/>
   </xsl:template>

   <!--PATTERN ACK_Lab-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ACK_Lab</svrl:text>

	  <!--RULE -->
   <xsl:template match="/" priority="1000" mode="M13">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab): In de instance werd tenminste één van de volgende elementen verwacht: descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013Lab ACK - Acknowledgement Message-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab ACK - Acknowledgement Message</svrl:text>

	  <!--RULE d20e22556-false-d955276e0-->
   <xsl:template match="/" priority="1223" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab): element hl7v2:MSH is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab): element hl7v2:MSH komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab): element hl7v2:MSA is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab): element hl7v2:MSA komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH" priority="1222" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.21 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.1" priority="1221" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Separator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Field Separator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.2" priority="1220" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('2') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('2') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Encoding Characters') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Encoding Characters' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3" priority="1219" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('3') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('3') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="1217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="1216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="1215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4" priority="1213" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('4') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('4') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="1211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="1210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="1209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5" priority="1207" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('5') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('5') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '5' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="1205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="1204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="1203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6" priority="1201" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('6') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('6') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '6' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="1199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="1198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="1197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7" priority="1195" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('7') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('7') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '7' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="1193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="1192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.8" priority="1190" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('8') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('8') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '8' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Security') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Security' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9" priority="1189" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('9') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('9') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '9' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MSG') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'MSG' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="1187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70076') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70076' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="1185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70003') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70003' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Trigger Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Trigger Event' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="1183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70354') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70354' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Structure') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Structure' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.10" priority="1181" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11" priority="1180" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('11') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('11') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '11' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'PT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="1178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70103') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70103' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="1176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70207') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70207' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12" priority="1174" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='2.5'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de elementinhoud van hl7v2:MSH.12 MOET ''2.5'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('12') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('12') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '12' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('VID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('VID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'VID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="1172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70104') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70104' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="1170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Internationalization Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Internationalization Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="1168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="1167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="1166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="1164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="1163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="1162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="1160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('International Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'International Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="1158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="1157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="1156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="1154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="1153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="1152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.13" priority="1150" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('13') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('13') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '13' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sequence Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.14" priority="1149" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '14' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Continuation Pointer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.15" priority="1148" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('15') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('15') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '15' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Accept Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.16" priority="1146" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('16') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('16') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '16' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Application Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.17" priority="1144" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NLD'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:MSH.17 MOET ''NLD'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('17') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('17') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '17' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.18" priority="1142" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('692') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('692') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '692' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70211') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70211' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Character Set') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Character Set' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19" priority="1140" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('693') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('693') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '693' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Principal Language Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="1138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="1137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="1136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="1134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="1133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="1132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.20" priority="1130" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1317') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1317') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1317' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70356') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70356' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Character Set Handling Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21" priority="1128" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1598') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1598') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1598' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Profile Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="1126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="1125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="1124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="1123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA" priority="1121" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.1" priority="1120" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('18') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('18') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '18' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70008') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70008') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Table MOET 'HL70008' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Acknowledgment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Acknowledgment Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Acknowledgment Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.2" priority="1118" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.3" priority="1117" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('20') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('20') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '20' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Text Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.4" priority="1116" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('21') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('21') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '21' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Expected Sequence Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.5" priority="1115" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('22') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('22') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '22' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delayed Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Delayed Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Delayed Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6" priority="1113" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('23') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('23') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '23' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Error Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.1"
                 priority="1111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.2"
                 priority="1110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.3"
                 priority="1109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.4"
                 priority="1107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.5"
                 priority="1106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.6"
                 priority="1105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR" priority="1103" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1" priority="1102" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('24') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('24') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '24' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ELD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ELD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ELD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Code and Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Code and Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Error Code and Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.1"
                 priority="1100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Segment ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.2"
                 priority="1099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment Sequence') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment Sequence') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Segment Sequence' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.3"
                 priority="1098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Position') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Position') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Field Position' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4"
                 priority="1097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Code Identifying Error') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Code Identifying Error') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Code Identifying Error' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.1"
                 priority="1095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.2"
                 priority="1094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.3"
                 priority="1093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.4"
                 priority="1091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.5"
                 priority="1090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.6"
                 priority="1089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2" priority="1087" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1812') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1812') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1812' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ERL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ERL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ERL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Error Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.1"
                 priority="1085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Segment ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.2"
                 priority="1084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment Sequence') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment Sequence') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Segment Sequence' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.3"
                 priority="1083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Position') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Position') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Field Position' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.4"
                 priority="1082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Repetition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Repetition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Field Repetition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.5"
                 priority="1081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Component Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Component Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Component Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.6"
                 priority="1080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sub-Component Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sub-Component Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Sub-Component Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3" priority="1079" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1813') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1813') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1813' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('HL7 Error Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('HL7 Error Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'HL7 Error Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.1"
                 priority="1077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.2"
                 priority="1076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.3"
                 priority="1075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.4"
                 priority="1073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.5"
                 priority="1072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.6"
                 priority="1071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.7"
                 priority="1069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.8"
                 priority="1068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.9"
                 priority="1067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.4" priority="1066" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1814') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1814') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1814' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70516') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70516') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70516' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Severity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Severity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Severity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5" priority="1064" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1815') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1815') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1815' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70533') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70533') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70533' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Error Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Error Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Application Error Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.1"
                 priority="1062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.2"
                 priority="1061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.3"
                 priority="1060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.4"
                 priority="1058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.5"
                 priority="1057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.6"
                 priority="1056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.7"
                 priority="1054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.8"
                 priority="1053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.9"
                 priority="1052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.6" priority="1051" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1816') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1816') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1816' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Error Parameter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Error Parameter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Application Error Parameter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7" priority="1050" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1817') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1817') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1817' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Diagnostic Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Diagnostic Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape"
                 priority="1049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape"
                 priority="1048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8" priority="1046" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1818') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1818') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1818' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('User Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'User Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape"
                 priority="1045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape"
                 priority="1044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.9" priority="1042" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1819') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1819') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1819' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70517') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70517') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70517' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Inform Person Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Inform Person Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Inform Person Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10" priority="1041" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1820') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1820') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1820' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70518') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70518') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70518' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Override Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Override Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Override Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.1"
                 priority="1039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.2"
                 priority="1038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.3"
                 priority="1037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.4"
                 priority="1035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.5"
                 priority="1034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.6"
                 priority="1033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.7"
                 priority="1031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.8"
                 priority="1030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.9"
                 priority="1029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11" priority="1028" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1821') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1821') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1821' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70519') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70519') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70519' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Override Reason Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Override Reason Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Override Reason Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.1"
                 priority="1026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.2"
                 priority="1025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.3"
                 priority="1024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.4"
                 priority="1022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.5"
                 priority="1021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.6"
                 priority="1020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.7"
                 priority="1018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.8"
                 priority="1017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.9"
                 priority="1016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12" priority="1015" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1822') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1822') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1822' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Help Desk Contact Point') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Help Desk Contact Point') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Help Desk Contact Point' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.1"
                 priority="1013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.2"
                 priority="1012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.3"
                 priority="1010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.4"
                 priority="1008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.5"
                 priority="1007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.6"
                 priority="1006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.7"
                 priority="1005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.8"
                 priority="1004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.9"
                 priority="1003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.10"
                 priority="1002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.11"
                 priority="1001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.12"
                 priority="1000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013-closedLab ACK - Acknowledgement Message-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab ACK - Acknowledgement Message</svrl:text>

	  <!--RULE d20e22556-true-d960409e0-->
   <xsl:template match="/*[not(self::hl7v2:MSH | self::hl7v2:MSA | self::hl7v2:ERR)]"
                 priority="1030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d20e22556-true-d960409e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH | hl7v2:MSA | hl7v2:ERR (rule-reference: d20e22556-true-d960409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e22609-true-d960439e0-->
   <xsl:template match="/hl7v2:MSH/*[not(self::hl7v2:MSH.1 | self::hl7v2:MSH.2 | self::hl7v2:MSH.3 | self::hl7v2:MSH.4 | self::hl7v2:MSH.5 | self::hl7v2:MSH.6 | self::hl7v2:MSH.7 | self::hl7v2:MSH.8 | self::hl7v2:MSH.9 | self::hl7v2:MSH.10 | self::hl7v2:MSH.11 | self::hl7v2:MSH.12 | self::hl7v2:MSH.13 | self::hl7v2:MSH.14 | self::hl7v2:MSH.15 | self::hl7v2:MSH.16 | self::hl7v2:MSH.17 | self::hl7v2:MSH.18 | self::hl7v2:MSH.19 | self::hl7v2:MSH.20 | self::hl7v2:MSH.21)]"
                 priority="1029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d20e22609-true-d960439e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH.1 | hl7v2:MSH.2 | hl7v2:MSH.3 | hl7v2:MSH.4 | hl7v2:MSH.5 | hl7v2:MSH.6 | hl7v2:MSH.7 | hl7v2:MSH.8 | hl7v2:MSH.9 | hl7v2:MSH.10 | hl7v2:MSH.11 | hl7v2:MSH.12 | hl7v2:MSH.13 | hl7v2:MSH.14 | hl7v2:MSH.15 | hl7v2:MSH.16 | hl7v2:MSH.17 | hl7v2:MSH.18 | hl7v2:MSH.19 | hl7v2:MSH.20 | hl7v2:MSH.21 (rule-reference: d20e22609-true-d960439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e35-true-d960463e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e35-true-d960463e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d960414e35-true-d960463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e61-true-d960493e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e61-true-d960493e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d960414e61-true-d960493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e99-true-d960523e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e99-true-d960523e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d960414e99-true-d960523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e128-true-d960553e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e128-true-d960553e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d960414e128-true-d960553e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e166-true-d960582e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e166-true-d960582e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d960414e166-true-d960582e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e212-true-d960612e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/*[not(self::hl7v2:MSG.1 | self::hl7v2:MSG.2 | self::hl7v2:MSG.3)]"
                 priority="1023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e212-true-d960612e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSG.1 | hl7v2:MSG.2 | hl7v2:MSG.3 (rule-reference: d960414e212-true-d960612e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e259-true-d960647e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/*[not(self::hl7v2:PT.1 | self::hl7v2:PT.2)]"
                 priority="1022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e259-true-d960647e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PT.1 | hl7v2:PT.2 (rule-reference: d960414e259-true-d960647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e286-true-d960671e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/*[not(self::hl7v2:VID.1 | self::hl7v2:VID.2 | self::hl7v2:VID.3)]"
                 priority="1021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e286-true-d960671e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:VID.1 | hl7v2:VID.2 | hl7v2:VID.3 (rule-reference: d960414e286-true-d960671e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960663e36-true-d960692e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960663e36-true-d960692e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d960663e36-true-d960692e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960663e55-true-d960743e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960663e55-true-d960743e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d960663e55-true-d960743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e464-true-d960830e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e464-true-d960830e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d960414e464-true-d960830e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960414e499-true-d960885e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960414e499-true-d960885e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d960414e499-true-d960885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e22611-true-d960924e0-->
   <xsl:template match="/hl7v2:MSA/*[not(self::hl7v2:MSA.1 | self::hl7v2:MSA.2 | self::hl7v2:MSA.3 | self::hl7v2:MSA.4 | self::hl7v2:MSA.5 | self::hl7v2:MSA.6)]"
                 priority="1016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d20e22611-true-d960924e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSA.1 | hl7v2:MSA.2 | hl7v2:MSA.3 | hl7v2:MSA.4 | hl7v2:MSA.5 | hl7v2:MSA.6 (rule-reference: d20e22611-true-d960924e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d960914e58-true-d960969e0-->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d960914e58-true-d960969e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d960914e58-true-d960969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e22613-true-d961026e0-->
   <xsl:template match="/hl7v2:ERR/*[not(self::hl7v2:ERR.1 | self::hl7v2:ERR.2 | self::hl7v2:ERR.3 | self::hl7v2:ERR.4 | self::hl7v2:ERR.5 | self::hl7v2:ERR.6 | self::hl7v2:ERR.7 | self::hl7v2:ERR.8 | self::hl7v2:ERR.9 | self::hl7v2:ERR.10 | self::hl7v2:ERR.11 | self::hl7v2:ERR.12)]"
                 priority="1014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d20e22613-true-d961026e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ERR.1 | hl7v2:ERR.2 | hl7v2:ERR.3 | hl7v2:ERR.4 | hl7v2:ERR.5 | hl7v2:ERR.6 | hl7v2:ERR.7 | hl7v2:ERR.8 | hl7v2:ERR.9 | hl7v2:ERR.10 | hl7v2:ERR.11 | hl7v2:ERR.12 (rule-reference: d20e22613-true-d961026e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e8-true-d961039e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/*[not(self::hl7v2:ELD.1 | self::hl7v2:ELD.2 | self::hl7v2:ELD.3 | self::hl7v2:ELD.4)]"
                 priority="1013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e8-true-d961039e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ELD.1 | hl7v2:ELD.2 | hl7v2:ELD.3 | hl7v2:ELD.4 (rule-reference: d961009e8-true-d961039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961030e48-true-d961072e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961030e48-true-d961072e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d961030e48-true-d961072e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e19-true-d961123e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/*[not(self::hl7v2:ERL.1 | self::hl7v2:ERL.2 | self::hl7v2:ERL.3 | self::hl7v2:ERL.4 | self::hl7v2:ERL.5 | self::hl7v2:ERL.6)]"
                 priority="1011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e19-true-d961123e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ERL.1 | hl7v2:ERL.2 | hl7v2:ERL.3 | hl7v2:ERL.4 | hl7v2:ERL.5 | hl7v2:ERL.6 (rule-reference: d961009e19-true-d961123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e30-true-d961177e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e30-true-d961177e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d961009e30-true-d961177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e56-true-d961255e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e56-true-d961255e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d961009e56-true-d961255e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e81-true-d961325e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/*[not(self::hl7v2:escape)]"
                 priority="1008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e81-true-d961325e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961009e81-true-d961325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961319e15-true-d961335e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961319e15-true-d961335e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961319e15-true-d961335e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961329e5-true-d961345e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961329e5-true-d961345e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961329e5-true-d961345e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e92-true-d961359e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/*[not(self::hl7v2:escape)]"
                 priority="1005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e92-true-d961359e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961009e92-true-d961359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961353e15-true-d961369e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961353e15-true-d961369e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961353e15-true-d961369e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961363e5-true-d961379e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961363e5-true-d961379e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d961363e5-true-d961379e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e116-true-d961407e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e116-true-d961407e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d961009e116-true-d961407e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e129-true-d961479e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e129-true-d961479e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d961009e129-true-d961479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d961009e142-true-d961554e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190214T125930/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.55-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ACK_Lab)/d961009e142-true-d961554e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d961009e142-true-d961554e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
</xsl:stylesheet>
